import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType, Gender } from '@12333/constants';
import * as orderServices from '@12333/services/api/Order';
import _ from 'lodash';
import { trim } from '@12333/utils';

export enum HomeOrderType {
  Recommend = 'Recommend',
  LastShelfTime = 'LastShelfTime',
}

export function useTaskList() {
  const searchValue = ref('');

  const DefaultQueryState = {
    gender: '' as any as Gender,
  };

  const queryState = reactive({
    searchValueTrim: '',
    orderType: HomeOrderType.Recommend,
    companyId: '',
    ...DefaultQueryState,
  });

  const handleSearch = _.debounce(function () {
    queryState.searchValueTrim = trim(searchValue.value);
  }, 300);

  const { infiniteLoadingProps } = useInfiniteLoading(
    ({ pageParam }) => {
      let params: API.FrontOrderListInput = {
        pageModel: {
          rows: 20,
          page: pageParam,
          orderInput: [
            queryState.orderType === HomeOrderType.Recommend
              ? { property: 'isRecommend', order: OrderInputType.Desc }
              : { property: 'lastShelfTime', order: OrderInputType.Desc },
          ],
        },
      };

      return orderServices.getFrontOrderList(params, {
        showLoading: false,
      });
    },
    {
      queryKey: ['orderServices/getFrontOrderList', queryState],
    }
  );

  return {
    searchValue,
    queryState,
    DefaultQueryState,
    handleSearch,
    infiniteLoadingProps,
  };
}
